summaryrefslogtreecommitdiff
path: root/test/unit/parser
diff options
context:
space:
mode:
Diffstat (limited to 'test/unit/parser')
-rw-r--r--test/unit/parser/parser_white.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/test/unit/parser/parser_white.h b/test/unit/parser/parser_white.h
index f4d104a93..270061c29 100644
--- a/test/unit/parser/parser_white.h
+++ b/test/unit/parser/parser_white.h
@@ -10,7 +10,7 @@
** See the file COPYING in the top-level source directory for licensing
** information.
**
** Black box testing of CVC4::parser::SmtParser.
**/
#include <cxxtest/TestSuite.h>
@@ -139,7 +139,7 @@ const string badSmtExprs[] = {
const int numBadSmtExprs = sizeof(badSmtExprs) / sizeof(string);
-class ParserBlack : public CxxTest::TestSuite {
+class ParserWhite : public CxxTest::TestSuite {
ExprManager *d_exprManager;
/* Set up declaration context for expr inputs */
@@ -227,7 +227,7 @@ class ParserBlack : public CxxTest::TestSuite {
} catch (Exception& e) {
cout << "\nGood expr failed:\n" << goodBooleanExprs[i] << endl;
cout << e;
- throw e;
+ throw;
}
}
}
@@ -10,7 +10,7 @@
** information.
**
- ** Black box testing of CVC4::parser::SmtParser.
+ ** White box testing of CVC4::parser::SmtParser.
**/
#include <cxxtest/TestSuite.h>
generated by cgit on debian on lair
contact matthew@masot.net with questions or feedback